Index: uspace/lib/libc/generic/malloc.c
===================================================================
--- uspace/lib/libc/generic/malloc.c	(revision d851f5974b98396e843431274d8bc2dbf4b293c3)
+++ uspace/lib/libc/generic/malloc.c	(revision 271283b93bbd61650607b4fab25deb72eab8fd21)
@@ -281,5 +281,5 @@
 				
 				if (cur->size >= real_size + excess) {
 					/* The current block is large enought to fit
 					   data in including alignment */
 					if ((void *) cur > heap_start) {
@@ -299,5 +299,5 @@
 						
 						if ((!prev_head->free) && (excess >= STRUCT_OVERHEAD)) {
 							/* The previous block is not free and there is enought
 							   space to fill in a new free block between the previous
 							   and current block */
@@ -317,5 +317,5 @@
 						/* The current block is the first block on the heap.
 						   We have to make sure that the alignment excess
-						   is large enought to fit a new free block just
+						   is large enough to fit a new free block just
 						   before the current block */
 						while (excess < STRUCT_OVERHEAD) {
@@ -281,5 +281,5 @@
 				
 				if (cur->size >= real_size + excess) {
-					/* The current block is large enought to fit
+					/* The current block is large enough to fit
 					   data in including alignment */
 					if ((void *) cur > heap_start) {
@@ -299,5 +299,5 @@
 						
 						if ((!prev_head->free) && (excess >= STRUCT_OVERHEAD)) {
-							/* The previous block is not free and there is enought
+							/* The previous block is not free and there is enough
 							   space to fill in a new free block between the previous
 							   and current block */
